(*
 * The LOOP Project
 *
 * The LOOP Team, Dresden University and Nijmegen University
 *
 * Copyright (C) 2002
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License in file COPYING in this or one of the
 * parent directories for more details.
 *
 * Created 2.5.02 by Hendrik
 *
 * Time-stamp: <Wednesday 30 July 03 15:27:50 tews@ithif51.inf.tu-dresden.de>
 *
 * part of global.ml that is configurable
 *
 * $Id: config.mli,v 1.3 2003/08/21 15:14:59 tews Exp $
 *
 *)



    (* the path for the fixedpoints library
     *)

(* USE prelude gfp now
 * 
 * val fixedpointlib : string
 * 
 *)

(*** Local Variables: ***)
(*** version-control: t ***)
(*** kept-new-versions: 5 ***)
(*** delete-old-versions: t ***)
(*** time-stamp-line-limit: 30 ***)
(*** End: ***)
